# coding utf-8
import pytest

from ladybug_comfort.hi import heat_index, heat_index_warning_category

from ladybug.epw import EPW
from ladybug.datacollection import HourlyContinuousCollection
from ladybug.datatype.temperature import Temperature
from ladybug.datatype.thermalcondition import ThermalCondition


def test_heating_degree_time():
    """Test the heat_index function."""
    assert heat_index(32, 85) == pytest.approx(46.582479, rel=1e-3)
    assert heat_index(20, 50) == pytest.approx(19.3611, rel=1e-3)

    assert heat_index_warning_category(20) == 0
    assert heat_index_warning_category(30) == 1
    assert heat_index_warning_category(38) == 2
    assert heat_index_warning_category(44) == 3
    assert heat_index_warning_category(56) == 4


def test_heating_degree_time_collection():
    """Test the heat_index function with Data Collections."""
    calc_length = 8760
    relative_path = './tests/epw/chicago.epw'
    epw = EPW(relative_path)

    hourly_hi = HourlyContinuousCollection.compute_function_aligned(
        heat_index, [epw.dry_bulb_temperature, epw.relative_humidity],
        Temperature(), 'C')

    assert isinstance(hourly_hi, HourlyContinuousCollection)
    assert len(hourly_hi.values) == calc_length
    assert hourly_hi[4000] == pytest.approx(30.89833, rel=1e-3)

    hourly_category = HourlyContinuousCollection.compute_function_aligned(
        heat_index_warning_category, [hourly_hi], ThermalCondition(), 'condition')
    assert isinstance(hourly_category, HourlyContinuousCollection)
    assert len(hourly_category.values) == calc_length
    assert hourly_category[4000] == 1



# coding utf-8
import pytest

from ladybug_comfort.asv import actual_sensation_vote
from ladybug_comfort.asv import actual_sensation_vote_effect_category


def test_actual_sensation_vote():
    """Test the actual_sensation_vote function."""
    assert actual_sensation_vote(40, 10, 15, 10) == pytest.approx(-0.4090,
                                                                  rel=1e-3)
    assert actual_sensation_vote(20, 50, 34, 48) == pytest.approx(-3.1250,
                                                                  rel=1e-3)


def test_actual_sensation_vote_effect_category():
    """Test the actual_sensation_vote_effect_category function"""
    assert actual_sensation_vote_effect_category(2.5) == 2
    assert actual_sensation_vote_effect_category(1.4) == 1
    assert actual_sensation_vote_effect_category(0.5) == 0
    assert actual_sensation_vote_effect_category(-1.4) == -1
    assert actual_sensation_vote_effect_category(-2.5) == -2



# coding utf-8
import pytest

from ladybug_comfort.degreetime import heating_degree_time, cooling_degree_time

from ladybug.epw import EPW
from ladybug.datacollection import HourlyContinuousCollection
from ladybug.datatype.temperaturetime import HeatingDegreeTime, CoolingDegreeTime


def test_heating_degree_time():
    """Test the heating_degree_time function."""
    temperature = 5
    base_temp = 18
    assert heating_degree_time(temperature, base_temp) == base_temp - temperature

    temperature = 20
    base_temp = 18
    assert heating_degree_time(temperature, base_temp) == 0


def test_heating_degree_time_collection():
    """Test the heating_degree_time function with Data Collections."""
    calc_length = 8760
    relative_path = './tests/epw/chicago.epw'
    epw = EPW(relative_path)

    hourly_heat = HourlyContinuousCollection.compute_function_aligned(
        heating_degree_time, [epw.dry_bulb_temperature, 18],
        HeatingDegreeTime(), 'degC-hours')
    hourly_heat.convert_to_unit('degC-days')

    assert isinstance(hourly_heat, HourlyContinuousCollection)
    assert len(hourly_heat.values) == calc_length
    assert hourly_heat[0] == pytest.approx(1.004166, rel=1e-3)


def test_cooling_degree_time():
    """Test the cooling_degree_time function."""
    temperature = 30
    base_temp = 23
    assert cooling_degree_time(temperature, base_temp) == temperature - base_temp

    temperature = 20
    base_temp = 23
    assert cooling_degree_time(temperature, base_temp) == 0


def test_cooling_degree_time_collection():
    """Test the cooling_degree_time function with Data Collections."""
    calc_length = 8760
    relative_path = './tests/epw/chicago.epw'
    epw = EPW(relative_path)

    hourly_cool = HourlyContinuousCollection.compute_function_aligned(
        cooling_degree_time, [epw.dry_bulb_temperature, 23],
        CoolingDegreeTime(), 'degC-hours')
    hourly_cool.convert_to_unit('degC-days')

    assert isinstance(hourly_cool, HourlyContinuousCollection)
    assert len(hourly_cool.values) == calc_length
    assert hourly_cool[4000] == pytest.approx(0.3375, rel=1e-3)



# coding utf-8
import pytest

from ladybug_comfort.at import apparent_temperature, apparent_temperature_warning_category


def test_apparent_temperature():
    """Test the apparent_temperature function."""
    assert apparent_temperature(32, 85, 10) == pytest.approx(34.290083, rel=1e-3)
    assert apparent_temperature(20, 50, 15) == pytest.approx(9.3482423, rel=1e-3)

    assert apparent_temperature_warning_category(60) == 4
    assert apparent_temperature_warning_category(40) == 3
    assert apparent_temperature_warning_category(35) == 2
    assert apparent_temperature_warning_category(26) == 1
    assert apparent_temperature_warning_category(25) == 0
    assert apparent_temperature_warning_category(16) == -1
    assert apparent_temperature_warning_category(11) == -2
    assert apparent_temperature_warning_category(6) == -3
    assert apparent_temperature_warning_category(5) == -4
    assert apparent_temperature_warning_category(0) == -5
    assert apparent_temperature_warning_category(-5) == -6
